@@ -237,8 +237,16 @@ class Dbtools:
 		return df_split
 
 	@staticmethod
-	def find_max_min_date(dbpath, tablename, index_col, con, on='max'):
+	def find_max_min_date(tablename, index_col, dbpath=None, con=None, on='max'):
 		assert on in ['max', 'min'], 'on为max或者min'
+		if con:
+			pass
+		else:
+			if dbpath:
+				con = sqlite3.connect(dbpath)
+			else:
+				raise ValueError('参数dbpath和con至少输入一项')
+
 		date = None
 		if 'code' in index_col.split(','):
 			str_code = ' WHERE code in (1,16,905)'
@@ -568,7 +576,6 @@ class Dbtools:
 				for i in key_col_str.split(','):
 					if i not in index_col_str.split(','):
 						raise KeyError(f'想要创建的主键{i}必须包含在创建的索引里')
-
 			cursor.execute(
 				f'CREATE TABLE {tablename} ({str_sql}{sql_key})')
 
@@ -590,6 +597,8 @@ class Dbtools:
 
 
 if __name__ == '__main__':
+	import sqlite3
+	type(sqlite3.connect('D:/test.sqlite3'))
 	factor = Dbtools()
 	factor.creat_dbtable(
 		dbpath='D:/test.sqlite3',
